Class: GitPusshuTen::Hook
- Inherits:
-
Object
- Object
- GitPusshuTen::Hook
- Defined in:
- lib/gitpusshuten/hook.rb
Instance Attribute Summary collapse
-
#commands ⇒ Object
Stores the (parsed) commands that need to be run.
-
#name ⇒ Object
Stores the name of the performed hook.
-
#type ⇒ Object
Stores the type of hook (pre or post).
Instance Method Summary collapse
-
#initialize(options) ⇒ Hook
constructor
Initializes a new hook Takes a hash of parameters.
Constructor Details
#initialize(options) ⇒ Hook
Initializes a new hook Takes a hash of parameters
19 20 21 22 23 |
# File 'lib/gitpusshuten/hook.rb', line 19 def initialize() @name = [:name] @type = [:type] @commands = [:commands] end |
Instance Attribute Details
#commands ⇒ Object
Stores the (parsed) commands that need to be run
14 15 16 |
# File 'lib/gitpusshuten/hook.rb', line 14 def commands @commands end |
#name ⇒ Object
Stores the name of the performed hook
6 7 8 |
# File 'lib/gitpusshuten/hook.rb', line 6 def name @name end |
#type ⇒ Object
Stores the type of hook (pre or post)
10 11 12 |
# File 'lib/gitpusshuten/hook.rb', line 10 def type @type end |